@@ -11,17 +11,13 @@ This module
 """
 import logging
 import sys
-
-if False:  # `typing.TYPE_CHECKING` was introduced in 3.5.2
-    from typing import Type  # `typing.Type` was introduced in 3.5.2
+from typing import Type
 
 LOG = logging.getLogger(__name__)
 LOG.addHandler(logging.NullHandler())
 
-__version__ = "3.7.8"
-__version_info__ = tuple(
-    int(i) for i in __version__.split(".") if i.isdigit()
-)
+__version__ = "4.0.0"
+__version_info__ = tuple(int(i) for i in __version__.split(".") if i.isdigit())
 
 
 # There is nothing lower than logging.DEBUG (10) in the logging library,
@@ -64,7 +60,7 @@ def configure_logging(verbosity, filename=None, logformat=LOG_FORMAT):
 
     if not filename or filename in ("stderr", "stdout"):
         fileobj = getattr(sys, filename or "stderr")
-        handler_cls = logging.StreamHandler  # type: Type[logging.Handler]
+        handler_cls: Type[logging.Handler] = logging.StreamHandler
     else:
         fileobj = filename
         handler_cls = logging.FileHandler
